@@ -2,13 +2,9 @@
 #include "xthread.h"
 
 #include <errno.h>
-
-#include "EXTERN.h"
-#include "perl.h"
-#include "XSUB.h"
-
 #include <stddef.h>
 #include <stdlib.h>
+#include <string.h>
 #include <errno.h>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -40,6 +36,7 @@
 # include <unistd.h>
 # include <utime.h>
 # include <signal.h>
+# include <dirent.h>
 
 # ifndef EIO_STRUCT_DIRENT
 #  define EIO_STRUCT_DIRENT struct dirent
@@ -573,7 +570,7 @@ static ssize_t aio_readahead (int fd, off_t offset, size_t count, worker *self)
     {
       size_t len = todo < EIO_BUFSIZE ? todo : EIO_BUFSIZE;
 
-      pread (fd, aio_buf, len, offset);
+      pread (fd, eio_buf, len, offset);
       offset += len;
       todo   -= len;
     }
@@ -589,9 +586,9 @@ static ssize_t aio_readahead (int fd, off_t offset, size_t count, worker *self)
 
 static mutex_t readdirlock = X_MUTEX_INIT;
   
-static int readdir_r (DIR *dirp, X_DIRENT *ent, X_DIRENT **res)
+static int readdir_r (DIR *dirp, EIO_STRUCT_DIRENT *ent, EIO_STRUCT_DIRENT **res)
 {
-  X_DIRENT *e;
+  EIO_STRUCT_DIRENT *e;
   int errorno;
 
   X_LOCK (readdirlock);
